@@ -2,7 +2,7 @@ from abc import ABC, abstractmethod
 from enum import Enum
 from typing import Any, Callable, Dict, List, Optional, Tuple
 
-from omegaconf import MISSING
+from omegaconf import MISSING, DictConfig
 from sklearn.base import BaseEstimator
 
 
@@ -11,6 +11,25 @@ class Task(Enum):
     classification = 2
 
 
+class CacheUsage(Enum):
+    """
+    Determines how cache usage is handled. In the case of **loading** caches:
+
+    - `allow`: program might use cache; if found and could be restored
+    - `must`: program should fail if no cache found
+    - `never`: program should not load cache even if found
+
+    When **saving** caches:
+    - `allow`: program might save cache; no fatal error thrown when fails
+    - `must`: program must save cache; throws error if fails (e.g. due to out of memory)
+    - `never`: program does not try to save a cached version
+    """
+
+    allow = 1
+    must = 2
+    never = 3
+
+
 class IncompatibilityError(Exception):
     ...
 
@@ -29,7 +48,7 @@ class AbstractEstimator(ABC, BaseEstimator):
         ...
 
     @abstractmethod
-    def score(self, X, y):
+    def score(self, X, y, **kwargs):
         ...
 
 
@@ -42,37 +61,35 @@ class AbstractAdapter(ABC, BaseEstimator):
 
 
 class Callback(ABC):
-    def __init__(self):
-        self.config = None
-
-    def set_config(self, config: Dict):
-        self.config = config
-
-    def on_begin(self):
+    @abstractmethod
+    def on_begin(self, config: DictConfig):
         ...
 
+    @abstractmethod
     def on_config_update(self, config: Dict):
         ...
 
-    def on_log(self, msg: Any, *args: Any):
-        ...
-
+    @abstractmethod
     def on_metrics(self, metrics):
         ...
 
+    @abstractmethod
     def on_summary(self, summary: Dict):
         ...
 
+    @abstractmethod
     def on_end(self, exit_code: Optional[int] = None):
         ...
 
 
 class AbstractStorageProvider(ABC):
-    def __init__(self):
-        self.config = None
+    @abstractmethod
+    def get_load_dir(self) -> str:
+        ...
 
-    def set_config(self, config: Dict):
-        self.config = config
+    @abstractmethod
+    def get_save_dir(self) -> str:
+        ...
 
     @abstractmethod
     def save(self, filename: str, writer: Callable, mode: str = "w"):
@@ -92,7 +109,13 @@ class AbstractStorageProvider(ABC):
 
 
 class AbstractPipeline(AbstractEstimator, ABC):
-    ...
+    @abstractmethod
+    def prefit(self):
+        ...
+
+    @abstractmethod
+    def postfit(self):
+        ...
 
 
 class TerminalColor:
